@@ -16,7 +16,7 @@ our @EXPORT_OK = qw(
     is_hash     every    noop        identity
 );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use constant ARG_PLACE_HOLDER => {};
 
@@ -426,11 +426,11 @@ concise code.
 
 =head1 SUBROUTINES/METHODS
 
-=head2 inc
+=head2 incr
 
 Increments the supplied number by 1
 
-    inc(1)
+    incr(1)
 
     # => 2
 
